@@ -3,23 +3,21 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.001001'; # VERSION
+our $VERSION = '0.001002'; # VERSION
 
 use Moose::Role;
 use MooseX::RemoteHelper;
-use MooseX::Types::Common::Numeric  qw( PositiveOrZeroNum );
-use MooseX::Types::Locale::Currency qw( CurrencyCode      );
 
 has amount => (
 	remote_name => 'Amount',
-	isa         => PositiveOrZeroNum,
+	isa         => 'Num',
 	is          => 'ro',
 	required    => 1,
 );
 
 has currency => (
 	remote_name => 'Currency',
-	isa         => CurrencyCode,
+	isa         => 'Str',
 	is          => 'ro',
 	required    => 1,
 );
@@ -37,7 +35,7 @@ Business::PaperlessTrans::Request::Role::Money - Money Attributes
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
