@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.001001'; # VERSION
+our $VERSION = '0.001002'; # VERSION
 
 use Moose;
 
@@ -14,10 +14,6 @@ with qw(
 	Business::PaperlessTrans::Role::Address
 );
 
-use MooseX::Types::Common::String  qw( NonEmptySimpleStr );
-use MooseX::Types::Common::Numeric qw( SingleDigit       );
-use MooseX::Types::DateTime        qw( DateTime          );
-
 my $dt_fmt
 	= sub {
 		my ( $attr, $instance ) = @_;
@@ -25,31 +21,29 @@ my $dt_fmt
 	};
 
 has id_type => (
-	isa         => SingleDigit,
+	isa         => 'Int',
 	is          => 'ro',
 	required    => 1,
 	remote_name => 'IDType',
 );
 
 has number => (
-	isa         => NonEmptySimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 	remote_name => 'Number',
 	required    => 1,
 );
 
 has expiration => (
-	isa         => DateTime,
+	isa         => 'DateTime',
 	is          => 'ro',
-	coerce      => 1,
 	remote_name => 'Expiration',
 	serializer  => $dt_fmt,
 );
 
 has date_of_birth => (
-	isa         => DateTime,
+	isa         => 'DateTime',
 	is          => 'ro',
-	coerce      => 1,
 	remote_name => 'DOB',
 	serializer  => $dt_fmt,
 );
@@ -68,7 +62,7 @@ Business::PaperlessTrans::RequestPart::Identification - Identification
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
