@@ -3,23 +3,21 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.001001'; # VERSION
+our $VERSION = '0.001002'; # VERSION
 
 use Moose;
 
 extends 'Business::PaperlessTrans::MessagePart';
 
-use MooseX::Types::Common::String qw( NonEmptySimpleStr );
-
 has number => (
 	remote_name => 'Number',
-	isa         => NonEmptySimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 );
 
 has type => (
 	remote_name => 'Type',
-	isa         => NonEmptySimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 );
 
@@ -37,7 +35,7 @@ Business::PaperlessTrans::RequestPart::Phone - Phone
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
