@@ -3,36 +3,34 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.001001'; # VERSION
+our $VERSION = '0.001002'; # VERSION
 
 use Moose;
 extends 'Business::PaperlessTrans::MessagePart';
 
-use MooseX::Types::Common::String qw( SimpleStr );
 use Moose::Util::TypeConstraints  qw( enum      );
-use MooseX::Types::UUID           qw( UUID      );
 
 has transaction_id => (
 	remote_name => 'TransactionID',
-	isa         => UUID|SimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 );
 
 has code => (
 	remote_name => 'ResponseCode',
-	isa         => enum( [qw( 0 1 2 )] ),
+	isa         => 'Int',
 	is          => 'ro',
 );
 
 has message => (
 	remote_name => 'Message',
-	isa         => SimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 );
 
 has timestamp => (
 	remote_name => 'DateTimeStamp',
-	isa         => SimpleStr,
+	isa         => 'Str',
 	is          => 'ro',
 );
 
@@ -50,7 +48,7 @@ Business::PaperlessTrans::Response - Base Response
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 AUTHOR
 
